corsemall - serve JSON CORS for local JS dev
============================================

corsemall - CORS 'em all

.. image:: https://travis-ci.org/hvnsweeting/corsemall.svg?branch=master
    :target: https://travis-ci.org/hvnsweeting/corsemall

Installation
------------

By using pip::

    pip install corsemall

Usage
-----

To serve JSON files at path with CORS allowed for all, run::

  corsemall PATH

Features
--------

- Supports both Python2 and Python3
- Run on Linux, OSX, Windows

Authors
-------

Viet Hung Nguyen <hvn@familug.org>
